@@ -6,6 +6,7 @@
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
 #'@param xtr The variables to be used in the transient term of the error correction model
 #'@param includeIntercept Boolean whether the y-intercept should be included
+#'@param ... Additional arguments to be passed to the 'lm' function (careful in that the these may need to be modified for ecm or may not be appropriate!)
 #'@return an lm object representing an error correction model
 #'@details
 #'The general format of an ECM is \deqn{\Delta y = \beta_{0} + \beta_{1}\Delta x_{1,t} +...+ \beta_{i}\Delta x_{i,t} + \gamma(y_{t-1} - (\alpha_{1}x_{1,t-1} +...+ \alpha_{i}x_{i,t-1})).}
@@ -41,7 +42,7 @@
 #'
 #'@export
 #'@importFrom stats lm
-ecm <- function (y, xeq, xtr, includeIntercept = TRUE) {
+ecm <- function (y, xeq, xtr, includeIntercept = TRUE, ...) {
   if (sum(grepl("^delta|Lag1$", names(xtr))) > 0 | sum(grepl("^delta", names(xeq))) > 0) {
     warning("You have column name(s) in xeq or xtr that begin with 'delta' or end with 'Lag1'. It is strongly recommended that you change this, otherwise the function 'ecmpredict' may result in errors or incorrect predictions.")
   }
@@ -66,9 +67,9 @@ ecm <- function (y, xeq, xtr, includeIntercept = TRUE) {
   names(x) <- c(xtrnames, xeqnames, "yLag1")
   
   if (includeIntercept){
-    ecm <- lm(dy ~ ., data = x)
+    ecm <- lm(dy ~ ., data = x, ...)
   } else {
-    ecm <- lm(dy ~ . - 1, data = x)
+    ecm <- lm(dy ~ . - 1, data = x, ...)
   }
   
   return(ecm)
